"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

var _checkNodeVersion = _interopRequireDefault(require("check-node-version"));

var _child_process = require("child_process");

var _fs = require("fs");

var _path = require("path");

var pExec = function pExec(command) {
  return new Promise(function (resolve, reject) {
    // eslint-disable-next-line max-params
    (0, _child_process.exec)(command, function (error, stdout, stderr) {
      if (stderr) {
        console.error("stderr: ".concat(stderr));
      }

      if (error) {
        reject(error);
      }

      resolve(stdout);
    });
  });
};

var getAllFiles = function getAllFiles(dirPath) {
  var arrayOfFilesInput = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  var files = (0, _fs.readdirSync)(dirPath);
  var arrayOfFiles = arrayOfFilesInput;
  files.forEach(function (file) {
    if ((0, _fs.statSync)(dirPath + '/' + file).isDirectory()) {
      arrayOfFiles = getAllFiles(dirPath + '/' + file, arrayOfFiles);
    } else {
      arrayOfFiles.push((0, _path.join)(dirPath, '/', file));
    }
  });
  return arrayOfFiles;
};

var TMP_FOLDER = '/tmp/serverless-esbuild-bundle-analyzer';

function bundleVisualizer() {
  return _bundleVisualizer.apply(this, arguments);
}

function _bundleVisualizer() {
  _bundleVisualizer = (0, _asyncToGenerator2["default"])( /*#__PURE__*/_regenerator["default"].mark(function _callee() {
    var _slsFunction$package;

    var functionName, slsFunction, fullZipPath, functionZipName, TEMP_DIR_LOCATION, allFiles, handlerPath, metafileName, commandArray;
    return _regenerator["default"].wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            functionName = this.options.analyze;

            if (!(functionName === undefined)) {
              _context.next = 3;
              break;
            }

            return _context.abrupt("return");

          case 3:
            slsFunction = this.serverless.service.getFunction(functionName);
            fullZipPath = (_slsFunction$package = slsFunction["package"]) === null || _slsFunction$package === void 0 ? void 0 : _slsFunction$package.artifact;

            if (!(fullZipPath === undefined)) {
              _context.next = 8;
              break;
            }

            this.serverless.cli.log("\uD83E\uDD2F Analyze failed: function ".concat(functionName, " was not found"), 'ServerlessAnalyzeBundlePlugin', {
              color: 'red'
            });
            return _context.abrupt("return");

          case 8:
            functionZipName = (0, _path.parse)(fullZipPath).base;
            this.serverless.cli.log("\u23F3 Analyzing function ".concat(functionName), 'ServerlessAnalyzeBundlePlugin');
            TEMP_DIR_LOCATION = "".concat(TMP_FOLDER, "/").concat(functionZipName, "/").concat(new Date().getTime());
            _context.next = 13;
            return pExec("mkdir -p ".concat(TEMP_DIR_LOCATION));

          case 13:
            _context.next = 15;
            return pExec("unzip .serverless/".concat(functionZipName, " -d ").concat(TEMP_DIR_LOCATION));

          case 15:
            allFiles = getAllFiles("".concat(TEMP_DIR_LOCATION));
            handlerPath = slsFunction.handler.split('.')[0];
            metafileName = allFiles.filter(function (fileName) {
              return fileName.includes(handlerPath) && fileName.endsWith('-meta.json');
            })[0];

            if (metafileName) {
              _context.next = 21;
              break;
            }

            this.serverless.cli.log("\uD83E\uDD2F Analyze failed: function ".concat(functionName, " metadata was not found"), 'ServerlessAnalyzeBundlePlugin', {
              color: 'red'
            });
            return _context.abrupt("return");

          case 21:
            commandArray = ['--metadata', metafileName, '--filename', "".concat(TEMP_DIR_LOCATION, "/").concat(functionName, ".html"), '--open'];
            (0, _checkNodeVersion["default"])({
              yarn: '>=2'
            }, function (err) {
              if (err !== null) {
                commandArray.unshift('node_modules/.bin/esbuild-visualizer');
              } else {
                commandArray.unshift('yarn', 'esbuild-visualizer');
              }

              void pExec(commandArray.join(' '));
            });

          case 23:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, this);
  }));
  return _bundleVisualizer.apply(this, arguments);
}

var _default = bundleVisualizer;
exports["default"] = _default;
//# sourceMappingURL=bundleVisualizer.js.map